
import math, sys
import maya.OpenMaya as OpenMaya
import maya.OpenMayaMPx as OpenMayaMPx

myNodeId = OpenMaya.MTypeId(0x87000)

# Node definition
class myNode(OpenMayaMPx.MPxNode):
	# class variables
	input = OpenMaya.MObject()
	output = OpenMaya.MObject()
	
	def __init__(self):
		OpenMayaMPx.MPxNode.__init__(self)
		
	def compute(self,plug,dataBlock):
		if ( plug == myNode.output ):
			dataHandle = dataBlock.inputValue( myNode.input )
			result = dataHandle.asFloat()
			
			outputHandle = dataBlock.outputValue( myNode.output )
			outputHandle.setFloat( result )
			dataBlock.setClean( plug )
			return OpenMaya.kSuccess

		return OpenMaya.kUnknownParameter

# creator
def nodeCreator():
	return OpenMayaMPx.asMPxPtr( myNode() )

# initialize
def nodeInitialize():
	# input
	nAttr = OpenMaya.MFnNumericAttribute()
	myNode.input = nAttr.create( "input", "in", OpenMaya.MFnNumericData.kFloat, 0.0 )
	nAttr.setStorable(1)
	nAttr.setKeyable(1) # Attribute is keyable and will show up in the channel box
	
	# output
	nAttr = OpenMaya.MFnNumericAttribute()
	myNode.output = nAttr.create( "output", "out", OpenMaya.MFnNumericData.kFloat, 0.0 )
	nAttr.setWritable(0) # Attribute is read-only because it is an output attribute
	nAttr.setStorable(0)
	
	# add attributes
	myNode.addAttribute( myNode.input )
	myNode.addAttribute( myNode.output )

	# dirty flag propagation
	myNode.attributeAffects( myNode.input, myNode.output )
	
# initialize the script plug-in
def initializePlugin(mobject):
	mplugin = OpenMayaMPx.MFnPlugin(mobject)
	try:
		mplugin.registerNode( "MyNode", myNodeId, nodeCreator, nodeInitialize )
	except:
		sys.stderr.write( "Failed to register node: %s" % "MyNode" )
		raise

# uninitialize the script plug-in
def uninitializePlugin(mobject):
	mplugin = OpenMayaMPx.MFnPlugin(mobject)
	try:
		mplugin.deregisterNode( myNodeId )
	except:
		sys.stderr.write( "Failed to deregister node: %s" % "MyNode" )
		raise
	
